# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: server.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import card_pb2 as card__pb2
from biostarPython.service import finger_pb2 as finger__pb2
from biostarPython.service import user_pb2 as user__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='server.proto',
  package='server',
  syntax='proto3',
  serialized_options=_b('\n\031com.supremainc.sdk.serverP\001Z\026biostar/service/server'),
  serialized_pb=_b('\n\x0cserver.proto\x12\x06server\x1a\ncard.proto\x1a\x0c\x66inger.proto\x1a\nuser.proto\"\x90\x02\n\rServerRequest\x12$\n\x07reqType\x18\x01 \x01(\x0e\x32\x13.server.RequestType\x12\x10\n\x08\x64\x65viceID\x18\x02 \x01(\r\x12\r\n\x05seqNO\x18\x03 \x01(\r\x12(\n\tverifyReq\x18\x04 \x01(\x0b\x32\x15.server.VerifyRequest\x12,\n\x0bidentifyReq\x18\x05 \x01(\x0b\x32\x17.server.IdentifyRequest\x12.\n\x0cglobalAPBReq\x18\x06 \x01(\x0b\x32\x18.server.GlobalAPBRequest\x12\x30\n\ruserPhraseReq\x18\x07 \x01(\x0b\x32\x19.server.UserPhraseRequest\"_\n\rVerifyRequest\x12\x0e\n\x06isCard\x18\x01 \x01(\x08\x12\x1c\n\x08\x63\x61rdType\x18\x02 \x01(\x0e\x32\n.card.Type\x12\x10\n\x08\x63\x61rdData\x18\x03 \x01(\x0c\x12\x0e\n\x06userID\x18\x04 \x01(\t\"W\n\x0fIdentifyRequest\x12.\n\x0etemplateFormat\x18\x01 \x01(\x0e\x32\x16.finger.TemplateFormat\x12\x14\n\x0ctemplateData\x18\x02 \x01(\x0c\"#\n\x10GlobalAPBRequest\x12\x0f\n\x07userIDs\x18\x01 \x03(\t\"#\n\x11UserPhraseRequest\x12\x0e\n\x06userID\x18\x01 \x01(\t\"%\n\x10SubscribeRequest\x12\x11\n\tqueueSize\x18\x01 \x01(\x05\"\x14\n\x12UnsubscribeRequest\"\x15\n\x13UnsubscribeResponse\"~\n\x13HandleVerifyRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\r\n\x05seqNO\x18\x02 \x01(\r\x12(\n\x07\x65rrCode\x18\x03 \x01(\x0e\x32\x17.server.ServerErrorCode\x12\x1c\n\x04user\x18\x04 \x01(\x0b\x32\x0e.user.UserInfo\"\x16\n\x14HandleVerifyResponse\"\x80\x01\n\x15HandleIdentifyRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\r\n\x05seqNO\x18\x02 \x01(\r\x12(\n\x07\x65rrCode\x18\x03 \x01(\x0e\x32\x17.server.ServerErrorCode\x12\x1c\n\x04user\x18\x04 \x01(\x0b\x32\x0e.user.UserInfo\"\x18\n\x16HandleIdentifyResponse\"s\n\x16HandleGlobalAPBRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\r\n\x05seqNO\x18\x02 \x01(\r\x12(\n\x07\x65rrCode\x18\x03 \x01(\x0e\x32\x17.server.ServerErrorCode\x12\x0e\n\x06zoneID\x18\x04 \x01(\r\"\x19\n\x17HandleGlobalAPBResponse\"x\n\x17HandleUserPhraseRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\r\n\x05seqNO\x18\x02 \x01(\r\x12(\n\x07\x65rrCode\x18\x03 \x01(\x0e\x32\x17.server.ServerErrorCode\x12\x12\n\nuserPhrase\x18\x04 \x01(\t\"\x1a\n\x18HandleUserPhraseResponse*x\n\x0bRequestType\x12\x0e\n\nNO_REQUEST\x10\x00\x12\x12\n\x0eVERIFY_REQUEST\x10\x01\x12\x14\n\x10IDENTIFY_REQUEST\x10\x02\x12\x16\n\x12GLOBAL_APB_REQUEST\x10\x03\x12\x17\n\x13USER_PHRASE_REQUEST\x10\x04*\xb5\x01\n\x0fServerErrorCode\x12\x0b\n\x07SUCCESS\x10\x00\x12\x18\n\x0bVERIFY_FAIL\x10\xd3\xfd\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1a\n\rIDENTIFY_FAIL\x10\xd2\xfd\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1f\n\x12HARD_APB_VIOLATION\x10\xce\xf6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1f\n\x12SOFT_APB_VIOLATION\x10\xcd\xf6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1d\n\x10\x43\x41NNOT_FIND_USER\x10\xb6\xfa\xff\xff\xff\xff\xff\xff\xff\x01\x32\xd7\x03\n\x06Server\x12>\n\tSubscribe\x12\x18.server.SubscribeRequest\x1a\x15.server.ServerRequest0\x01\x12\x46\n\x0bUnsubscribe\x12\x1a.server.UnsubscribeRequest\x1a\x1b.server.UnsubscribeResponse\x12I\n\x0cHandleVerify\x12\x1b.server.HandleVerifyRequest\x1a\x1c.server.HandleVerifyResponse\x12O\n\x0eHandleIdentify\x12\x1d.server.HandleIdentifyRequest\x1a\x1e.server.HandleIdentifyResponse\x12R\n\x0fHandleGlobalAPB\x12\x1e.server.HandleGlobalAPBRequest\x1a\x1f.server.HandleGlobalAPBResponse\x12U\n\x10HandleUserPhrase\x12\x1f.server.HandleUserPhraseRequest\x1a .server.HandleUserPhraseResponseB5\n\x19\x63om.supremainc.sdk.serverP\x01Z\x16\x62iostar/service/serverb\x06proto3')
  ,
  dependencies=[card__pb2.DESCRIPTOR,finger__pb2.DESCRIPTOR,user__pb2.DESCRIPTOR,])

_REQUESTTYPE = _descriptor.EnumDescriptor(
  name='RequestType',
  full_name='server.RequestType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_REQUEST', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_REQUEST', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IDENTIFY_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GLOBAL_APB_REQUEST', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_PHRASE_REQUEST', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1284,
  serialized_end=1404,
)
_sym_db.RegisterEnumDescriptor(_REQUESTTYPE)

RequestType = enum_type_wrapper.EnumTypeWrapper(_REQUESTTYPE)
_SERVERERRORCODE = _descriptor.EnumDescriptor(
  name='ServerErrorCode',
  full_name='server.ServerErrorCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_FAIL', index=1, number=-301,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IDENTIFY_FAIL', index=2, number=-302,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HARD_APB_VIOLATION', index=3, number=-1202,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOFT_APB_VIOLATION', index=4, number=-1203,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_FIND_USER', index=5, number=-714,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1407,
  serialized_end=1588,
)
_sym_db.RegisterEnumDescriptor(_SERVERERRORCODE)

ServerErrorCode = enum_type_wrapper.EnumTypeWrapper(_SERVERERRORCODE)
NO_REQUEST = 0
VERIFY_REQUEST = 1
IDENTIFY_REQUEST = 2
GLOBAL_APB_REQUEST = 3
USER_PHRASE_REQUEST = 4
SUCCESS = 0
VERIFY_FAIL = -301
IDENTIFY_FAIL = -302
HARD_APB_VIOLATION = -1202
SOFT_APB_VIOLATION = -1203
CANNOT_FIND_USER = -714



_SERVERREQUEST = _descriptor.Descriptor(
  name='ServerRequest',
  full_name='server.ServerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reqType', full_name='server.ServerRequest.reqType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='server.ServerRequest.deviceID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNO', full_name='server.ServerRequest.seqNO', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='verifyReq', full_name='server.ServerRequest.verifyReq', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifyReq', full_name='server.ServerRequest.identifyReq', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='globalAPBReq', full_name='server.ServerRequest.globalAPBReq', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userPhraseReq', full_name='server.ServerRequest.userPhraseReq', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=335,
)


_VERIFYREQUEST = _descriptor.Descriptor(
  name='VerifyRequest',
  full_name='server.VerifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isCard', full_name='server.VerifyRequest.isCard', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardType', full_name='server.VerifyRequest.cardType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardData', full_name='server.VerifyRequest.cardData', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='server.VerifyRequest.userID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=432,
)


_IDENTIFYREQUEST = _descriptor.Descriptor(
  name='IdentifyRequest',
  full_name='server.IdentifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='templateFormat', full_name='server.IdentifyRequest.templateFormat', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateData', full_name='server.IdentifyRequest.templateData', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=521,
)


_GLOBALAPBREQUEST = _descriptor.Descriptor(
  name='GlobalAPBRequest',
  full_name='server.GlobalAPBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userIDs', full_name='server.GlobalAPBRequest.userIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=523,
  serialized_end=558,
)


_USERPHRASEREQUEST = _descriptor.Descriptor(
  name='UserPhraseRequest',
  full_name='server.UserPhraseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='server.UserPhraseRequest.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=560,
  serialized_end=595,
)


_SUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='SubscribeRequest',
  full_name='server.SubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queueSize', full_name='server.SubscribeRequest.queueSize', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=597,
  serialized_end=634,
)


_UNSUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='UnsubscribeRequest',
  full_name='server.UnsubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=636,
  serialized_end=656,
)


_UNSUBSCRIBERESPONSE = _descriptor.Descriptor(
  name='UnsubscribeResponse',
  full_name='server.UnsubscribeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=658,
  serialized_end=679,
)


_HANDLEVERIFYREQUEST = _descriptor.Descriptor(
  name='HandleVerifyRequest',
  full_name='server.HandleVerifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='server.HandleVerifyRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNO', full_name='server.HandleVerifyRequest.seqNO', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errCode', full_name='server.HandleVerifyRequest.errCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='server.HandleVerifyRequest.user', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=681,
  serialized_end=807,
)


_HANDLEVERIFYRESPONSE = _descriptor.Descriptor(
  name='HandleVerifyResponse',
  full_name='server.HandleVerifyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=831,
)


_HANDLEIDENTIFYREQUEST = _descriptor.Descriptor(
  name='HandleIdentifyRequest',
  full_name='server.HandleIdentifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='server.HandleIdentifyRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNO', full_name='server.HandleIdentifyRequest.seqNO', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errCode', full_name='server.HandleIdentifyRequest.errCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='server.HandleIdentifyRequest.user', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=962,
)


_HANDLEIDENTIFYRESPONSE = _descriptor.Descriptor(
  name='HandleIdentifyResponse',
  full_name='server.HandleIdentifyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=964,
  serialized_end=988,
)


_HANDLEGLOBALAPBREQUEST = _descriptor.Descriptor(
  name='HandleGlobalAPBRequest',
  full_name='server.HandleGlobalAPBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='server.HandleGlobalAPBRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNO', full_name='server.HandleGlobalAPBRequest.seqNO', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errCode', full_name='server.HandleGlobalAPBRequest.errCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zoneID', full_name='server.HandleGlobalAPBRequest.zoneID', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=990,
  serialized_end=1105,
)


_HANDLEGLOBALAPBRESPONSE = _descriptor.Descriptor(
  name='HandleGlobalAPBResponse',
  full_name='server.HandleGlobalAPBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1132,
)


_HANDLEUSERPHRASEREQUEST = _descriptor.Descriptor(
  name='HandleUserPhraseRequest',
  full_name='server.HandleUserPhraseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='server.HandleUserPhraseRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNO', full_name='server.HandleUserPhraseRequest.seqNO', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errCode', full_name='server.HandleUserPhraseRequest.errCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userPhrase', full_name='server.HandleUserPhraseRequest.userPhrase', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1254,
)


_HANDLEUSERPHRASERESPONSE = _descriptor.Descriptor(
  name='HandleUserPhraseResponse',
  full_name='server.HandleUserPhraseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1282,
)

_SERVERREQUEST.fields_by_name['reqType'].enum_type = _REQUESTTYPE
_SERVERREQUEST.fields_by_name['verifyReq'].message_type = _VERIFYREQUEST
_SERVERREQUEST.fields_by_name['identifyReq'].message_type = _IDENTIFYREQUEST
_SERVERREQUEST.fields_by_name['globalAPBReq'].message_type = _GLOBALAPBREQUEST
_SERVERREQUEST.fields_by_name['userPhraseReq'].message_type = _USERPHRASEREQUEST
_VERIFYREQUEST.fields_by_name['cardType'].enum_type = card__pb2._TYPE
_IDENTIFYREQUEST.fields_by_name['templateFormat'].enum_type = finger__pb2._TEMPLATEFORMAT
_HANDLEVERIFYREQUEST.fields_by_name['errCode'].enum_type = _SERVERERRORCODE
_HANDLEVERIFYREQUEST.fields_by_name['user'].message_type = user__pb2._USERINFO
_HANDLEIDENTIFYREQUEST.fields_by_name['errCode'].enum_type = _SERVERERRORCODE
_HANDLEIDENTIFYREQUEST.fields_by_name['user'].message_type = user__pb2._USERINFO
_HANDLEGLOBALAPBREQUEST.fields_by_name['errCode'].enum_type = _SERVERERRORCODE
_HANDLEUSERPHRASEREQUEST.fields_by_name['errCode'].enum_type = _SERVERERRORCODE
DESCRIPTOR.message_types_by_name['ServerRequest'] = _SERVERREQUEST
DESCRIPTOR.message_types_by_name['VerifyRequest'] = _VERIFYREQUEST
DESCRIPTOR.message_types_by_name['IdentifyRequest'] = _IDENTIFYREQUEST
DESCRIPTOR.message_types_by_name['GlobalAPBRequest'] = _GLOBALAPBREQUEST
DESCRIPTOR.message_types_by_name['UserPhraseRequest'] = _USERPHRASEREQUEST
DESCRIPTOR.message_types_by_name['SubscribeRequest'] = _SUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['UnsubscribeRequest'] = _UNSUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['UnsubscribeResponse'] = _UNSUBSCRIBERESPONSE
DESCRIPTOR.message_types_by_name['HandleVerifyRequest'] = _HANDLEVERIFYREQUEST
DESCRIPTOR.message_types_by_name['HandleVerifyResponse'] = _HANDLEVERIFYRESPONSE
DESCRIPTOR.message_types_by_name['HandleIdentifyRequest'] = _HANDLEIDENTIFYREQUEST
DESCRIPTOR.message_types_by_name['HandleIdentifyResponse'] = _HANDLEIDENTIFYRESPONSE
DESCRIPTOR.message_types_by_name['HandleGlobalAPBRequest'] = _HANDLEGLOBALAPBREQUEST
DESCRIPTOR.message_types_by_name['HandleGlobalAPBResponse'] = _HANDLEGLOBALAPBRESPONSE
DESCRIPTOR.message_types_by_name['HandleUserPhraseRequest'] = _HANDLEUSERPHRASEREQUEST
DESCRIPTOR.message_types_by_name['HandleUserPhraseResponse'] = _HANDLEUSERPHRASERESPONSE
DESCRIPTOR.enum_types_by_name['RequestType'] = _REQUESTTYPE
DESCRIPTOR.enum_types_by_name['ServerErrorCode'] = _SERVERERRORCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServerRequest = _reflection.GeneratedProtocolMessageType('ServerRequest', (_message.Message,), dict(
  DESCRIPTOR = _SERVERREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.ServerRequest)
  ))
_sym_db.RegisterMessage(ServerRequest)

VerifyRequest = _reflection.GeneratedProtocolMessageType('VerifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.VerifyRequest)
  ))
_sym_db.RegisterMessage(VerifyRequest)

IdentifyRequest = _reflection.GeneratedProtocolMessageType('IdentifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _IDENTIFYREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.IdentifyRequest)
  ))
_sym_db.RegisterMessage(IdentifyRequest)

GlobalAPBRequest = _reflection.GeneratedProtocolMessageType('GlobalAPBRequest', (_message.Message,), dict(
  DESCRIPTOR = _GLOBALAPBREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.GlobalAPBRequest)
  ))
_sym_db.RegisterMessage(GlobalAPBRequest)

UserPhraseRequest = _reflection.GeneratedProtocolMessageType('UserPhraseRequest', (_message.Message,), dict(
  DESCRIPTOR = _USERPHRASEREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.UserPhraseRequest)
  ))
_sym_db.RegisterMessage(UserPhraseRequest)

SubscribeRequest = _reflection.GeneratedProtocolMessageType('SubscribeRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBEREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.SubscribeRequest)
  ))
_sym_db.RegisterMessage(SubscribeRequest)

UnsubscribeRequest = _reflection.GeneratedProtocolMessageType('UnsubscribeRequest', (_message.Message,), dict(
  DESCRIPTOR = _UNSUBSCRIBEREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.UnsubscribeRequest)
  ))
_sym_db.RegisterMessage(UnsubscribeRequest)

UnsubscribeResponse = _reflection.GeneratedProtocolMessageType('UnsubscribeResponse', (_message.Message,), dict(
  DESCRIPTOR = _UNSUBSCRIBERESPONSE,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.UnsubscribeResponse)
  ))
_sym_db.RegisterMessage(UnsubscribeResponse)

HandleVerifyRequest = _reflection.GeneratedProtocolMessageType('HandleVerifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEVERIFYREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleVerifyRequest)
  ))
_sym_db.RegisterMessage(HandleVerifyRequest)

HandleVerifyResponse = _reflection.GeneratedProtocolMessageType('HandleVerifyResponse', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEVERIFYRESPONSE,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleVerifyResponse)
  ))
_sym_db.RegisterMessage(HandleVerifyResponse)

HandleIdentifyRequest = _reflection.GeneratedProtocolMessageType('HandleIdentifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEIDENTIFYREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleIdentifyRequest)
  ))
_sym_db.RegisterMessage(HandleIdentifyRequest)

HandleIdentifyResponse = _reflection.GeneratedProtocolMessageType('HandleIdentifyResponse', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEIDENTIFYRESPONSE,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleIdentifyResponse)
  ))
_sym_db.RegisterMessage(HandleIdentifyResponse)

HandleGlobalAPBRequest = _reflection.GeneratedProtocolMessageType('HandleGlobalAPBRequest', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEGLOBALAPBREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleGlobalAPBRequest)
  ))
_sym_db.RegisterMessage(HandleGlobalAPBRequest)

HandleGlobalAPBResponse = _reflection.GeneratedProtocolMessageType('HandleGlobalAPBResponse', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEGLOBALAPBRESPONSE,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleGlobalAPBResponse)
  ))
_sym_db.RegisterMessage(HandleGlobalAPBResponse)

HandleUserPhraseRequest = _reflection.GeneratedProtocolMessageType('HandleUserPhraseRequest', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEUSERPHRASEREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleUserPhraseRequest)
  ))
_sym_db.RegisterMessage(HandleUserPhraseRequest)

HandleUserPhraseResponse = _reflection.GeneratedProtocolMessageType('HandleUserPhraseResponse', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEUSERPHRASERESPONSE,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleUserPhraseResponse)
  ))
_sym_db.RegisterMessage(HandleUserPhraseResponse)


DESCRIPTOR._options = None

_SERVER = _descriptor.ServiceDescriptor(
  name='Server',
  full_name='server.Server',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1591,
  serialized_end=2062,
  methods=[
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='server.Server.Subscribe',
    index=0,
    containing_service=None,
    input_type=_SUBSCRIBEREQUEST,
    output_type=_SERVERREQUEST,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Unsubscribe',
    full_name='server.Server.Unsubscribe',
    index=1,
    containing_service=None,
    input_type=_UNSUBSCRIBEREQUEST,
    output_type=_UNSUBSCRIBERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HandleVerify',
    full_name='server.Server.HandleVerify',
    index=2,
    containing_service=None,
    input_type=_HANDLEVERIFYREQUEST,
    output_type=_HANDLEVERIFYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HandleIdentify',
    full_name='server.Server.HandleIdentify',
    index=3,
    containing_service=None,
    input_type=_HANDLEIDENTIFYREQUEST,
    output_type=_HANDLEIDENTIFYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HandleGlobalAPB',
    full_name='server.Server.HandleGlobalAPB',
    index=4,
    containing_service=None,
    input_type=_HANDLEGLOBALAPBREQUEST,
    output_type=_HANDLEGLOBALAPBRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HandleUserPhrase',
    full_name='server.Server.HandleUserPhrase',
    index=5,
    containing_service=None,
    input_type=_HANDLEUSERPHRASEREQUEST,
    output_type=_HANDLEUSERPHRASERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVER)

DESCRIPTOR.services_by_name['Server'] = _SERVER

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cert.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cert.proto',
  package='cert',
  syntax='proto3',
  serialized_options=_b('\n\027com.supremainc.sdk.certP\001Z\024biostar/service/cert'),
  serialized_pb=_b('\n\ncert.proto\x12\x04\x63\x65rt\"~\n\x07PKIName\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\t\x12\x10\n\x08province\x18\x02 \x01(\t\x12\x0c\n\x04\x63ity\x18\x03 \x01(\t\x12\x14\n\x0corganization\x18\x04 \x01(\t\x12\x18\n\x10organizationUnit\x18\x05 \x01(\t\x12\x12\n\ncommonName\x18\x06 \x01(\t\"\x80\x01\n\x1e\x43reateServerCertificateRequest\x12\x1e\n\x07subject\x18\x01 \x01(\x0b\x32\r.cert.PKIName\x12\x13\n\x0b\x64omainNames\x18\x02 \x03(\t\x12\x0f\n\x07IPAddrs\x18\x03 \x03(\t\x12\x18\n\x10\x65xpireAfterYears\x18\x04 \x01(\x05\"H\n\x1f\x43reateServerCertificateResponse\x12\x12\n\nserverCert\x18\x01 \x01(\t\x12\x11\n\tserverKey\x18\x02 \x01(\t\"D\n\x1bSetServerCertificateRequest\x12\x12\n\nserverCert\x18\x01 \x01(\t\x12\x11\n\tserverKey\x18\x02 \x01(\t\"\x1e\n\x1cSetServerCertificateResponse\"G\n\x1cSetGatewayCertificateRequest\x12\x13\n\x0bgatewayCert\x18\x01 \x01(\t\x12\x12\n\ngatewayKey\x18\x02 \x01(\t\"\x1f\n\x1dSetGatewayCertificateResponse2\xaf\x02\n\x04\x43\x65rt\x12\x66\n\x17\x43reateServerCertificate\x12$.cert.CreateServerCertificateRequest\x1a%.cert.CreateServerCertificateResponse\x12]\n\x14SetServerCertificate\x12!.cert.SetServerCertificateRequest\x1a\".cert.SetServerCertificateResponse\x12`\n\x15SetGatewayCertificate\x12\".cert.SetGatewayCertificateRequest\x1a#.cert.SetGatewayCertificateResponseB1\n\x17\x63om.supremainc.sdk.certP\x01Z\x14\x62iostar/service/certb\x06proto3')
)




_PKINAME = _descriptor.Descriptor(
  name='PKIName',
  full_name='cert.PKIName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='country', full_name='cert.PKIName.country', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='province', full_name='cert.PKIName.province', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='city', full_name='cert.PKIName.city', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='organization', full_name='cert.PKIName.organization', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='organizationUnit', full_name='cert.PKIName.organizationUnit', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commonName', full_name='cert.PKIName.commonName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20,
  serialized_end=146,
)


_CREATESERVERCERTIFICATEREQUEST = _descriptor.Descriptor(
  name='CreateServerCertificateRequest',
  full_name='cert.CreateServerCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='cert.CreateServerCertificateRequest.subject', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domainNames', full_name='cert.CreateServerCertificateRequest.domainNames', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='IPAddrs', full_name='cert.CreateServerCertificateRequest.IPAddrs', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expireAfterYears', full_name='cert.CreateServerCertificateRequest.expireAfterYears', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=277,
)


_CREATESERVERCERTIFICATERESPONSE = _descriptor.Descriptor(
  name='CreateServerCertificateResponse',
  full_name='cert.CreateServerCertificateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverCert', full_name='cert.CreateServerCertificateResponse.serverCert', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverKey', full_name='cert.CreateServerCertificateResponse.serverKey', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=351,
)


_SETSERVERCERTIFICATEREQUEST = _descriptor.Descriptor(
  name='SetServerCertificateRequest',
  full_name='cert.SetServerCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='serverCert', full_name='cert.SetServerCertificateRequest.serverCert', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverKey', full_name='cert.SetServerCertificateRequest.serverKey', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=353,
  serialized_end=421,
)


_SETSERVERCERTIFICATERESPONSE = _descriptor.Descriptor(
  name='SetServerCertificateResponse',
  full_name='cert.SetServerCertificateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=453,
)


_SETGATEWAYCERTIFICATEREQUEST = _descriptor.Descriptor(
  name='SetGatewayCertificateRequest',
  full_name='cert.SetGatewayCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayCert', full_name='cert.SetGatewayCertificateRequest.gatewayCert', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gatewayKey', full_name='cert.SetGatewayCertificateRequest.gatewayKey', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=526,
)


_SETGATEWAYCERTIFICATERESPONSE = _descriptor.Descriptor(
  name='SetGatewayCertificateResponse',
  full_name='cert.SetGatewayCertificateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=559,
)

_CREATESERVERCERTIFICATEREQUEST.fields_by_name['subject'].message_type = _PKINAME
DESCRIPTOR.message_types_by_name['PKIName'] = _PKINAME
DESCRIPTOR.message_types_by_name['CreateServerCertificateRequest'] = _CREATESERVERCERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['CreateServerCertificateResponse'] = _CREATESERVERCERTIFICATERESPONSE
DESCRIPTOR.message_types_by_name['SetServerCertificateRequest'] = _SETSERVERCERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['SetServerCertificateResponse'] = _SETSERVERCERTIFICATERESPONSE
DESCRIPTOR.message_types_by_name['SetGatewayCertificateRequest'] = _SETGATEWAYCERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['SetGatewayCertificateResponse'] = _SETGATEWAYCERTIFICATERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PKIName = _reflection.GeneratedProtocolMessageType('PKIName', (_message.Message,), dict(
  DESCRIPTOR = _PKINAME,
  __module__ = 'cert_pb2'
  # @@protoc_insertion_point(class_scope:cert.PKIName)
  ))
_sym_db.RegisterMessage(PKIName)

CreateServerCertificateRequest = _reflection.GeneratedProtocolMessageType('CreateServerCertificateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATESERVERCERTIFICATEREQUEST,
  __module__ = 'cert_pb2'
  # @@protoc_insertion_point(class_scope:cert.CreateServerCertificateRequest)
  ))
_sym_db.RegisterMessage(CreateServerCertificateRequest)

CreateServerCertificateResponse = _reflection.GeneratedProtocolMessageType('CreateServerCertificateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATESERVERCERTIFICATERESPONSE,
  __module__ = 'cert_pb2'
  # @@protoc_insertion_point(class_scope:cert.CreateServerCertificateResponse)
  ))
_sym_db.RegisterMessage(CreateServerCertificateResponse)

SetServerCertificateRequest = _reflection.GeneratedProtocolMessageType('SetServerCertificateRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETSERVERCERTIFICATEREQUEST,
  __module__ = 'cert_pb2'
  # @@protoc_insertion_point(class_scope:cert.SetServerCertificateRequest)
  ))
_sym_db.RegisterMessage(SetServerCertificateRequest)

SetServerCertificateResponse = _reflection.GeneratedProtocolMessageType('SetServerCertificateResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETSERVERCERTIFICATERESPONSE,
  __module__ = 'cert_pb2'
  # @@protoc_insertion_point(class_scope:cert.SetServerCertificateResponse)
  ))
_sym_db.RegisterMessage(SetServerCertificateResponse)

SetGatewayCertificateRequest = _reflection.GeneratedProtocolMessageType('SetGatewayCertificateRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETGATEWAYCERTIFICATEREQUEST,
  __module__ = 'cert_pb2'
  # @@protoc_insertion_point(class_scope:cert.SetGatewayCertificateRequest)
  ))
_sym_db.RegisterMessage(SetGatewayCertificateRequest)

SetGatewayCertificateResponse = _reflection.GeneratedProtocolMessageType('SetGatewayCertificateResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETGATEWAYCERTIFICATERESPONSE,
  __module__ = 'cert_pb2'
  # @@protoc_insertion_point(class_scope:cert.SetGatewayCertificateResponse)
  ))
_sym_db.RegisterMessage(SetGatewayCertificateResponse)


DESCRIPTOR._options = None

_CERT = _descriptor.ServiceDescriptor(
  name='Cert',
  full_name='cert.Cert',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=562,
  serialized_end=865,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateServerCertificate',
    full_name='cert.Cert.CreateServerCertificate',
    index=0,
    containing_service=None,
    input_type=_CREATESERVERCERTIFICATEREQUEST,
    output_type=_CREATESERVERCERTIFICATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetServerCertificate',
    full_name='cert.Cert.SetServerCertificate',
    index=1,
    containing_service=None,
    input_type=_SETSERVERCERTIFICATEREQUEST,
    output_type=_SETSERVERCERTIFICATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetGatewayCertificate',
    full_name='cert.Cert.SetGatewayCertificate',
    index=2,
    containing_service=None,
    input_type=_SETGATEWAYCERTIFICATEREQUEST,
    output_type=_SETGATEWAYCERTIFICATERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CERT)

DESCRIPTOR.services_by_name['Cert'] = _CERT

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: login.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='login.proto',
  package='login',
  syntax='proto3',
  serialized_options=_b('\n\030com.supremainc.sdk.loginP\001Z\025biostar/service/login'),
  serialized_pb=_b('\n\x0blogin.proto\x12\x05login\"\"\n\x0cLoginRequest\x12\x12\n\ntenantCert\x18\x01 \x01(\t\"!\n\rLoginResponse\x12\x10\n\x08jwtToken\x18\x01 \x01(\t\">\n\x11LoginAdminRequest\x12\x17\n\x0f\x61\x64minTenantCert\x18\x01 \x01(\t\x12\x10\n\x08tenantID\x18\x02 \x01(\t\"&\n\x12LoginAdminResponse\x12\x10\n\x08jwtToken\x18\x01 \x01(\t\"\x0f\n\rLogoutRequest\"\x10\n\x0eLogoutResponse2\xb5\x01\n\x05Login\x12\x32\n\x05Login\x12\x13.login.LoginRequest\x1a\x14.login.LoginResponse\x12\x41\n\nLoginAdmin\x12\x18.login.LoginAdminRequest\x1a\x19.login.LoginAdminResponse\x12\x35\n\x06Logout\x12\x14.login.LogoutRequest\x1a\x15.login.LogoutResponseB3\n\x18\x63om.supremainc.sdk.loginP\x01Z\x15\x62iostar/service/loginb\x06proto3')
)




_LOGINREQUEST = _descriptor.Descriptor(
  name='LoginRequest',
  full_name='login.LoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantCert', full_name='login.LoginRequest.tenantCert', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=56,
)


_LOGINRESPONSE = _descriptor.Descriptor(
  name='LoginResponse',
  full_name='login.LoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jwtToken', full_name='login.LoginResponse.jwtToken', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=91,
)


_LOGINADMINREQUEST = _descriptor.Descriptor(
  name='LoginAdminRequest',
  full_name='login.LoginAdminRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='adminTenantCert', full_name='login.LoginAdminRequest.adminTenantCert', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='login.LoginAdminRequest.tenantID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=155,
)


_LOGINADMINRESPONSE = _descriptor.Descriptor(
  name='LoginAdminResponse',
  full_name='login.LoginAdminResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jwtToken', full_name='login.LoginAdminResponse.jwtToken', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=195,
)


_LOGOUTREQUEST = _descriptor.Descriptor(
  name='LogoutRequest',
  full_name='login.LogoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=212,
)


_LOGOUTRESPONSE = _descriptor.Descriptor(
  name='LogoutResponse',
  full_name='login.LogoutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=230,
)

DESCRIPTOR.message_types_by_name['LoginRequest'] = _LOGINREQUEST
DESCRIPTOR.message_types_by_name['LoginResponse'] = _LOGINRESPONSE
DESCRIPTOR.message_types_by_name['LoginAdminRequest'] = _LOGINADMINREQUEST
DESCRIPTOR.message_types_by_name['LoginAdminResponse'] = _LOGINADMINRESPONSE
DESCRIPTOR.message_types_by_name['LogoutRequest'] = _LOGOUTREQUEST
DESCRIPTOR.message_types_by_name['LogoutResponse'] = _LOGOUTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LoginRequest = _reflection.GeneratedProtocolMessageType('LoginRequest', (_message.Message,), dict(
  DESCRIPTOR = _LOGINREQUEST,
  __module__ = 'login_pb2'
  # @@protoc_insertion_point(class_scope:login.LoginRequest)
  ))
_sym_db.RegisterMessage(LoginRequest)

LoginResponse = _reflection.GeneratedProtocolMessageType('LoginResponse', (_message.Message,), dict(
  DESCRIPTOR = _LOGINRESPONSE,
  __module__ = 'login_pb2'
  # @@protoc_insertion_point(class_scope:login.LoginResponse)
  ))
_sym_db.RegisterMessage(LoginResponse)

LoginAdminRequest = _reflection.GeneratedProtocolMessageType('LoginAdminRequest', (_message.Message,), dict(
  DESCRIPTOR = _LOGINADMINREQUEST,
  __module__ = 'login_pb2'
  # @@protoc_insertion_point(class_scope:login.LoginAdminRequest)
  ))
_sym_db.RegisterMessage(LoginAdminRequest)

LoginAdminResponse = _reflection.GeneratedProtocolMessageType('LoginAdminResponse', (_message.Message,), dict(
  DESCRIPTOR = _LOGINADMINRESPONSE,
  __module__ = 'login_pb2'
  # @@protoc_insertion_point(class_scope:login.LoginAdminResponse)
  ))
_sym_db.RegisterMessage(LoginAdminResponse)

LogoutRequest = _reflection.GeneratedProtocolMessageType('LogoutRequest', (_message.Message,), dict(
  DESCRIPTOR = _LOGOUTREQUEST,
  __module__ = 'login_pb2'
  # @@protoc_insertion_point(class_scope:login.LogoutRequest)
  ))
_sym_db.RegisterMessage(LogoutRequest)

LogoutResponse = _reflection.GeneratedProtocolMessageType('LogoutResponse', (_message.Message,), dict(
  DESCRIPTOR = _LOGOUTRESPONSE,
  __module__ = 'login_pb2'
  # @@protoc_insertion_point(class_scope:login.LogoutResponse)
  ))
_sym_db.RegisterMessage(LogoutResponse)


DESCRIPTOR._options = None

_LOGIN = _descriptor.ServiceDescriptor(
  name='Login',
  full_name='login.Login',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=233,
  serialized_end=414,
  methods=[
  _descriptor.MethodDescriptor(
    name='Login',
    full_name='login.Login.Login',
    index=0,
    containing_service=None,
    input_type=_LOGINREQUEST,
    output_type=_LOGINRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LoginAdmin',
    full_name='login.Login.LoginAdmin',
    index=1,
    containing_service=None,
    input_type=_LOGINADMINREQUEST,
    output_type=_LOGINADMINRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Logout',
    full_name='login.Login.Logout',
    index=2,
    containing_service=None,
    input_type=_LOGOUTREQUEST,
    output_type=_LOGOUTRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOGIN)

DESCRIPTOR.services_by_name['Login'] = _LOGIN

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: finger.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='finger.proto',
  package='finger',
  syntax='proto3',
  serialized_options=_b('\n\031com.supremainc.sdk.fingerP\001Z\026biostar/service/finger'),
  serialized_pb=_b('\n\x0c\x66inger.proto\x12\x06\x66inger\x1a\terr.proto\"<\n\nFingerData\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0c\n\x04\x66lag\x18\x02 \x01(\r\x12\x11\n\ttemplates\x18\x03 \x03(\x0c\"i\n\x0bScanRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12.\n\x0etemplateFormat\x18\x02 \x01(\x0e\x32\x16.finger.TemplateFormat\x12\x18\n\x10qualityThreshold\x18\x03 \x01(\r\":\n\x0cScanResponse\x12\x14\n\x0ctemplateData\x18\x01 \x01(\x0c\x12\x14\n\x0cqualityScore\x18\x02 \x01(\r\"#\n\x0fGetImageRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"$\n\x10GetImageResponse\x12\x10\n\x08\x42MPImage\x18\x01 \x01(\x0c\"I\n\rVerifyRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12&\n\nfingerData\x18\x02 \x01(\x0b\x32\x12.finger.FingerData\"\x10\n\x0eVerifyResponse\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"9\n\x11GetConfigResponse\x12$\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x14.finger.FingerConfig\"J\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.finger.FingerConfig\"\x13\n\x11SetConfigResponse\"P\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.finger.FingerConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"\xca\x02\n\x0c\x46ingerConfig\x12,\n\rsecurityLevel\x18\x01 \x01(\x0e\x32\x15.finger.SecurityLevel\x12\"\n\x08\x66\x61stMode\x18\x02 \x01(\x0e\x32\x10.finger.FastMode\x12(\n\x0bsensitivity\x18\x03 \x01(\x0e\x32\x13.finger.Sensitivity\x12&\n\nsensorMode\x18\x04 \x01(\x0e\x32\x12.finger.SensorMode\x12.\n\x0etemplateFormat\x18\x05 \x01(\x0e\x32\x16.finger.TemplateFormat\x12\x13\n\x0bscanTimeout\x18\x06 \x01(\x05\x12\x1a\n\x12\x61\x64vancedEnrollment\x18\x07 \x01(\x08\x12\x11\n\tshowImage\x18\x08 \x01(\x08\x12\"\n\x08LFDLevel\x18\t \x01(\x0e\x32\x10.finger.LFDLevel*`\n\x0eTemplateFormat\x12\x1b\n\x17TEMPLATE_FORMAT_SUPREMA\x10\x00\x12\x17\n\x13TEMPLATE_FORMAT_ISO\x10\x01\x12\x18\n\x14TEMPLATE_FORMAT_ANSI\x10\x02*W\n\rSecurityLevel\x12\n\n\x06SECURE\x10\x00\x12\x0f\n\x0bMORE_SECURE\x10\x01\x12\x0f\n\x0bMOST_SECURE\x10\x02\x12\x14\n\x10\x44\x45\x46\x41ULT_SECURITY\x10\x00\x1a\x02\x10\x01*R\n\x08\x46\x61stMode\x12\r\n\tAUTOMATIC\x10\x00\x12\x08\n\x04\x46\x41ST\x10\x01\x12\n\n\x06\x46\x41STER\x10\x02\x12\x0b\n\x07\x46\x41STEST\x10\x03\x12\x10\n\x0c\x44\x45\x46\x41ULT_FAST\x10\x00\x1a\x02\x10\x01*\x85\x02\n\x0bSensitivity\x12\x14\n\x10LOWEST_SENSITIVE\x10\x00\x12\x14\n\x10LEVEL0_SENSITIVE\x10\x00\x12\x14\n\x10LEVEL1_SENSITIVE\x10\x01\x12\x14\n\x10LEVEL2_SENSITIVE\x10\x02\x12\x14\n\x10LEVEL3_SENSITIVE\x10\x03\x12\x14\n\x10LEVEL4_SENSITIVE\x10\x04\x12\x14\n\x10LEVEL5_SENSITIVE\x10\x05\x12\x14\n\x10LEVEL6_SENSITIVE\x10\x06\x12\x14\n\x10LEVEL7_SENSITIVE\x10\x07\x12\x15\n\x11HIGHEST_SENSITIVE\x10\x07\x12\x15\n\x11\x44\x45\x46\x41ULT_SENSITITY\x10\x07\x1a\x02\x10\x01*T\n\nSensorMode\x12\r\n\tALWAYS_ON\x10\x00\x12\x1a\n\x16\x41\x43TIVATED_BY_PROXIMITY\x10\x01\x12\x17\n\x13\x44\x45\x46\x41ULT_SENSOR_MODE\x10\x00\x1a\x02\x10\x01*[\n\x08LFDLevel\x12\x0c\n\x08NOT_USED\x10\x00\x12\n\n\x06STRICT\x10\x01\x12\x0f\n\x0bMORE_STRICT\x10\x02\x12\x0f\n\x0bMOST_STRICT\x10\x03\x12\x0f\n\x0b\x44\x45\x46\x41ULT_LFD\x10\x00\x1a\x02\x10\x01\x32\x88\x03\n\x06\x46inger\x12\x31\n\x04Scan\x12\x13.finger.ScanRequest\x1a\x14.finger.ScanResponse\x12=\n\x08GetImage\x12\x17.finger.GetImageRequest\x1a\x18.finger.GetImageResponse\x12\x37\n\x06Verify\x12\x15.finger.VerifyRequest\x1a\x16.finger.VerifyResponse\x12@\n\tGetConfig\x12\x18.finger.GetConfigRequest\x1a\x19.finger.GetConfigResponse\x12@\n\tSetConfig\x12\x18.finger.SetConfigRequest\x1a\x19.finger.SetConfigResponse\x12O\n\x0eSetConfigMulti\x12\x1d.finger.SetConfigMultiRequest\x1a\x1e.finger.SetConfigMultiResponseB5\n\x19\x63om.supremainc.sdk.fingerP\x01Z\x16\x62iostar/service/fingerb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_TEMPLATEFORMAT = _descriptor.EnumDescriptor(
  name='TemplateFormat',
  full_name='finger.TemplateFormat',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TEMPLATE_FORMAT_SUPREMA', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEMPLATE_FORMAT_ISO', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEMPLATE_FORMAT_ANSI', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1109,
  serialized_end=1205,
)
_sym_db.RegisterEnumDescriptor(_TEMPLATEFORMAT)

TemplateFormat = enum_type_wrapper.EnumTypeWrapper(_TEMPLATEFORMAT)
_SECURITYLEVEL = _descriptor.EnumDescriptor(
  name='SecurityLevel',
  full_name='finger.SecurityLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SECURE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MORE_SECURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOST_SECURE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_SECURITY', index=3, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=1207,
  serialized_end=1294,
)
_sym_db.RegisterEnumDescriptor(_SECURITYLEVEL)

SecurityLevel = enum_type_wrapper.EnumTypeWrapper(_SECURITYLEVEL)
_FASTMODE = _descriptor.EnumDescriptor(
  name='FastMode',
  full_name='finger.FastMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTOMATIC', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAST', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FASTER', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FASTEST', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_FAST', index=4, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=1296,
  serialized_end=1378,
)
_sym_db.RegisterEnumDescriptor(_FASTMODE)

FastMode = enum_type_wrapper.EnumTypeWrapper(_FASTMODE)
_SENSITIVITY = _descriptor.EnumDescriptor(
  name='Sensitivity',
  full_name='finger.Sensitivity',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOWEST_SENSITIVE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL0_SENSITIVE', index=1, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL1_SENSITIVE', index=2, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL2_SENSITIVE', index=3, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL3_SENSITIVE', index=4, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL4_SENSITIVE', index=5, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL5_SENSITIVE', index=6, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL6_SENSITIVE', index=7, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL7_SENSITIVE', index=8, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HIGHEST_SENSITIVE', index=9, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_SENSITITY', index=10, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=1381,
  serialized_end=1642,
)
_sym_db.RegisterEnumDescriptor(_SENSITIVITY)

Sensitivity = enum_type_wrapper.EnumTypeWrapper(_SENSITIVITY)
_SENSORMODE = _descriptor.EnumDescriptor(
  name='SensorMode',
  full_name='finger.SensorMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALWAYS_ON', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTIVATED_BY_PROXIMITY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_SENSOR_MODE', index=2, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=1644,
  serialized_end=1728,
)
_sym_db.RegisterEnumDescriptor(_SENSORMODE)

SensorMode = enum_type_wrapper.EnumTypeWrapper(_SENSORMODE)
_LFDLEVEL = _descriptor.EnumDescriptor(
  name='LFDLevel',
  full_name='finger.LFDLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_USED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRICT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MORE_STRICT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOST_STRICT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_LFD', index=4, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=1730,
  serialized_end=1821,
)
_sym_db.RegisterEnumDescriptor(_LFDLEVEL)

LFDLevel = enum_type_wrapper.EnumTypeWrapper(_LFDLEVEL)
TEMPLATE_FORMAT_SUPREMA = 0
TEMPLATE_FORMAT_ISO = 1
TEMPLATE_FORMAT_ANSI = 2
SECURE = 0
MORE_SECURE = 1
MOST_SECURE = 2
DEFAULT_SECURITY = 0
AUTOMATIC = 0
FAST = 1
FASTER = 2
FASTEST = 3
DEFAULT_FAST = 0
LOWEST_SENSITIVE = 0
LEVEL0_SENSITIVE = 0
LEVEL1_SENSITIVE = 1
LEVEL2_SENSITIVE = 2
LEVEL3_SENSITIVE = 3
LEVEL4_SENSITIVE = 4
LEVEL5_SENSITIVE = 5
LEVEL6_SENSITIVE = 6
LEVEL7_SENSITIVE = 7
HIGHEST_SENSITIVE = 7
DEFAULT_SENSITITY = 7
ALWAYS_ON = 0
ACTIVATED_BY_PROXIMITY = 1
DEFAULT_SENSOR_MODE = 0
NOT_USED = 0
STRICT = 1
MORE_STRICT = 2
MOST_STRICT = 3
DEFAULT_LFD = 0



_FINGERDATA = _descriptor.Descriptor(
  name='FingerData',
  full_name='finger.FingerData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='finger.FingerData.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flag', full_name='finger.FingerData.flag', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templates', full_name='finger.FingerData.templates', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=95,
)


_SCANREQUEST = _descriptor.Descriptor(
  name='ScanRequest',
  full_name='finger.ScanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='finger.ScanRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateFormat', full_name='finger.ScanRequest.templateFormat', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualityThreshold', full_name='finger.ScanRequest.qualityThreshold', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=202,
)


_SCANRESPONSE = _descriptor.Descriptor(
  name='ScanResponse',
  full_name='finger.ScanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='templateData', full_name='finger.ScanResponse.templateData', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualityScore', full_name='finger.ScanResponse.qualityScore', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=262,
)


_GETIMAGEREQUEST = _descriptor.Descriptor(
  name='GetImageRequest',
  full_name='finger.GetImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='finger.GetImageRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=299,
)


_GETIMAGERESPONSE = _descriptor.Descriptor(
  name='GetImageResponse',
  full_name='finger.GetImageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='BMPImage', full_name='finger.GetImageResponse.BMPImage', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=337,
)


_VERIFYREQUEST = _descriptor.Descriptor(
  name='VerifyRequest',
  full_name='finger.VerifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='finger.VerifyRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fingerData', full_name='finger.VerifyRequest.fingerData', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=412,
)


_VERIFYRESPONSE = _descriptor.Descriptor(
  name='VerifyResponse',
  full_name='finger.VerifyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=430,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='finger.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='finger.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=468,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='finger.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='finger.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=470,
  serialized_end=527,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='finger.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='finger.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='finger.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=603,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='finger.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=605,
  serialized_end=624,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='finger.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='finger.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='finger.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=706,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='finger.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='finger.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=774,
)


_FINGERCONFIG = _descriptor.Descriptor(
  name='FingerConfig',
  full_name='finger.FingerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='securityLevel', full_name='finger.FingerConfig.securityLevel', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fastMode', full_name='finger.FingerConfig.fastMode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensitivity', full_name='finger.FingerConfig.sensitivity', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorMode', full_name='finger.FingerConfig.sensorMode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateFormat', full_name='finger.FingerConfig.templateFormat', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scanTimeout', full_name='finger.FingerConfig.scanTimeout', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='advancedEnrollment', full_name='finger.FingerConfig.advancedEnrollment', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='showImage', full_name='finger.FingerConfig.showImage', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='LFDLevel', full_name='finger.FingerConfig.LFDLevel', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=777,
  serialized_end=1107,
)

_SCANREQUEST.fields_by_name['templateFormat'].enum_type = _TEMPLATEFORMAT
_VERIFYREQUEST.fields_by_name['fingerData'].message_type = _FINGERDATA
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _FINGERCONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _FINGERCONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _FINGERCONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_FINGERCONFIG.fields_by_name['securityLevel'].enum_type = _SECURITYLEVEL
_FINGERCONFIG.fields_by_name['fastMode'].enum_type = _FASTMODE
_FINGERCONFIG.fields_by_name['sensitivity'].enum_type = _SENSITIVITY
_FINGERCONFIG.fields_by_name['sensorMode'].enum_type = _SENSORMODE
_FINGERCONFIG.fields_by_name['templateFormat'].enum_type = _TEMPLATEFORMAT
_FINGERCONFIG.fields_by_name['LFDLevel'].enum_type = _LFDLEVEL
DESCRIPTOR.message_types_by_name['FingerData'] = _FINGERDATA
DESCRIPTOR.message_types_by_name['ScanRequest'] = _SCANREQUEST
DESCRIPTOR.message_types_by_name['ScanResponse'] = _SCANRESPONSE
DESCRIPTOR.message_types_by_name['GetImageRequest'] = _GETIMAGEREQUEST
DESCRIPTOR.message_types_by_name['GetImageResponse'] = _GETIMAGERESPONSE
DESCRIPTOR.message_types_by_name['VerifyRequest'] = _VERIFYREQUEST
DESCRIPTOR.message_types_by_name['VerifyResponse'] = _VERIFYRESPONSE
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.message_types_by_name['FingerConfig'] = _FINGERCONFIG
DESCRIPTOR.enum_types_by_name['TemplateFormat'] = _TEMPLATEFORMAT
DESCRIPTOR.enum_types_by_name['SecurityLevel'] = _SECURITYLEVEL
DESCRIPTOR.enum_types_by_name['FastMode'] = _FASTMODE
DESCRIPTOR.enum_types_by_name['Sensitivity'] = _SENSITIVITY
DESCRIPTOR.enum_types_by_name['SensorMode'] = _SENSORMODE
DESCRIPTOR.enum_types_by_name['LFDLevel'] = _LFDLEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FingerData = _reflection.GeneratedProtocolMessageType('FingerData', (_message.Message,), dict(
  DESCRIPTOR = _FINGERDATA,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.FingerData)
  ))
_sym_db.RegisterMessage(FingerData)

ScanRequest = _reflection.GeneratedProtocolMessageType('ScanRequest', (_message.Message,), dict(
  DESCRIPTOR = _SCANREQUEST,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.ScanRequest)
  ))
_sym_db.RegisterMessage(ScanRequest)

ScanResponse = _reflection.GeneratedProtocolMessageType('ScanResponse', (_message.Message,), dict(
  DESCRIPTOR = _SCANRESPONSE,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.ScanResponse)
  ))
_sym_db.RegisterMessage(ScanResponse)

GetImageRequest = _reflection.GeneratedProtocolMessageType('GetImageRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETIMAGEREQUEST,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.GetImageRequest)
  ))
_sym_db.RegisterMessage(GetImageRequest)

GetImageResponse = _reflection.GeneratedProtocolMessageType('GetImageResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETIMAGERESPONSE,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.GetImageResponse)
  ))
_sym_db.RegisterMessage(GetImageResponse)

VerifyRequest = _reflection.GeneratedProtocolMessageType('VerifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYREQUEST,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.VerifyRequest)
  ))
_sym_db.RegisterMessage(VerifyRequest)

VerifyResponse = _reflection.GeneratedProtocolMessageType('VerifyResponse', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYRESPONSE,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.VerifyResponse)
  ))
_sym_db.RegisterMessage(VerifyResponse)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)

FingerConfig = _reflection.GeneratedProtocolMessageType('FingerConfig', (_message.Message,), dict(
  DESCRIPTOR = _FINGERCONFIG,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.FingerConfig)
  ))
_sym_db.RegisterMessage(FingerConfig)


DESCRIPTOR._options = None
_SECURITYLEVEL._options = None
_FASTMODE._options = None
_SENSITIVITY._options = None
_SENSORMODE._options = None
_LFDLEVEL._options = None

_FINGER = _descriptor.ServiceDescriptor(
  name='Finger',
  full_name='finger.Finger',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1824,
  serialized_end=2216,
  methods=[
  _descriptor.MethodDescriptor(
    name='Scan',
    full_name='finger.Finger.Scan',
    index=0,
    containing_service=None,
    input_type=_SCANREQUEST,
    output_type=_SCANRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetImage',
    full_name='finger.Finger.GetImage',
    index=1,
    containing_service=None,
    input_type=_GETIMAGEREQUEST,
    output_type=_GETIMAGERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Verify',
    full_name='finger.Finger.Verify',
    index=2,
    containing_service=None,
    input_type=_VERIFYREQUEST,
    output_type=_VERIFYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='finger.Finger.GetConfig',
    index=3,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='finger.Finger.SetConfig',
    index=4,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='finger.Finger.SetConfigMulti',
    index=5,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_FINGER)

DESCRIPTOR.services_by_name['Finger'] = _FINGER

# @@protoc_insertion_point(module_scope)
